From e2aa991e10ffd924a828ec149951f2f20eecead2 Mon Sep 17 00:00:00 2001
From: Lunny Xiao <xiaolunwen@gmail.com>
Date: Fri, 11 Nov 2016 21:56:35 +0800
Subject: [PATCH] ask for go get from code.gitea.io/gitea and change gogs to
 gitea on main file (#146)

---
 main.go | 9 +++++----
 1 file changed, 5 insertions(+), 4 deletions(-)

diff --git a/main.go b/main.go
index 4151441307..7670877f21 100644
--- a/main.go
+++ b/main.go
@@ -1,9 +1,10 @@
+// Copyright 2016 The Gitea Authors. All rights reserved.
 // Copyright 2014 The Gogs Authors. All rights reserved.
 // Use of this source code is governed by a MIT-style
 // license that can be found in the LICENSE file.
 
-// Gogs (Go Git Service) is a painless self-hosted Git Service.
-package main
+// Gitea (git with a cup of tea) is a painless self-hosted Git Service.
+package main // import "code.gitea.io/gitea"
 
 import (
 	"log"
@@ -25,8 +26,8 @@ func init() {
 
 func main() {
 	app := cli.NewApp()
-	app.Name = "Gogs"
-	app.Usage = "Go Git Service: a painless self-hosted Git service"
+	app.Name = "Gitea"
+	app.Usage = "A painless self-hosted Git service"
 	app.Version = Version
 	app.Commands = []cli.Command{
 		cmd.CmdWeb,